@@ -32,7 +32,7 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
     def __init__(self, config: Config, context: Context) -> None:
         self._config = config
         self._context = context
-        self._http_client = aiohttp.ClientSession(config.url)
+        self._http_client = aiohttp.ClientSession()
 
     async def _on_start(self) -> None:
         self._producer = AIOKafkaProducer(
@@ -62,12 +62,12 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
         source_ids: list[int],
         server_name: str = 'unknown',
         timeout: int = 5
-    ) -> bool:
-        logger.info(
+    ) -> list[int]:
+        logger.debug(
             f'mark notification for user({user_id}) as read for sources({source_type}): {source_ids}'
         )
         async with self._http_client.post(
-            '/v1/mark_notifications_as_read_internal',
+            f'{self._config.url}/v1/mark_notifications_as_read_internal',
             json={
                 'user_id': user_id,
                 'source_type': source_type,
@@ -79,7 +79,7 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
             timeout=timeout,
         ) as response:
             logger.info(
-                f'mark notification as read done, status: {response.status} {response.reason}'
+                f'mark notification as read done, status: {response.status}'
             )
 
             answer = await response.json()
@@ -87,6 +87,6 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
             result = answer.get('result', False)
             error = answer.get('error', None)
             if not done:
-                logger.error(f'mark notification as read failed, error: {error}')
+                logger.debug(f'mark notification as read failed, error: {error}')
                 raise NotificationsServerError(f'mark notification as read failed, error: {error}')
             return result
